searchData={"items":[{"type":"protocol","title":"IOData","doc":"A protocol for working with various data types such as binaries and iolists.\n\nThis protocol defines a set of functions for performing common operations on\ndata, including:\n\n- Checking if the data has at least a specified number of bytes.\n- Retrieving the size of the data in bytes.\n- Splitting the data at a specified byte offset.\n- Checking if the data starts with a given binary prefix.\n- Converting the data to iodata or binary formats.\n- Extracting portions of the data as iodata or binary.\n\nImplementations of this protocol should be efficient and avoid unnecessary\ncopying of data whenever possible.","ref":"IOData.html"},{"type":"function","title":"IOData.at_least?/2","doc":"Checks if the given data has at least the specified number of bytes.","ref":"IOData.html#at_least?/2"},{"type":"function","title":"IOData.size/1","doc":"Returns the total size, in bytes, of the given data.","ref":"IOData.html#size/1"},{"type":"function","title":"IOData.slice/2","doc":"Returns a slice of the data, with a tuple that defines the start and count of bytes to extract.","ref":"IOData.html#slice/2"},{"type":"function","title":"IOData.slice/3","doc":"Returns a slice of the data, starting at 'start' for 'count' bytes.","ref":"IOData.html#slice/3"},{"type":"function","title":"IOData.slice!/2","doc":"Same as slice/2 but raises an error if the data is insufficient.","ref":"IOData.html#slice!/2"},{"type":"function","title":"IOData.slice!/3","doc":"Same as slice/3 but raises an error if the data is insufficient.","ref":"IOData.html#slice!/3"},{"type":"function","title":"IOData.split/2","doc":"Splits data at the specified byte offset if possible, returning either {:ok, {prefix, suffix}} or an error tuple.","ref":"IOData.html#split/2"},{"type":"function","title":"IOData.split!/2","doc":"Same as split/2 but raises an error if the data is insufficient.","ref":"IOData.html#split!/2"},{"type":"function","title":"IOData.starts_with?/2","doc":"Checks if the given data starts with the specified binary prefix.","ref":"IOData.html#starts_with?/2"},{"type":"type","title":"IOData.t/0","doc":"","ref":"IOData.html#t:t/0"},{"type":"function","title":"IOData.to_binary/1","doc":"Converts the entire data into a binary.","ref":"IOData.html#to_binary/1"},{"type":"function","title":"IOData.to_binary/3","doc":"Extracts a portion of the data as a binary, starting at 'start' for 'count' bytes. Returns an ok/error tuple.","ref":"IOData.html#to_binary/3"},{"type":"function","title":"IOData.to_binary!/1","doc":"Same as to_binary/1 but raises an error if the data is insufficient.","ref":"IOData.html#to_binary!/1"},{"type":"function","title":"IOData.to_binary!/3","doc":"Same as to_binary/3 but raises an error if the data is insufficient.","ref":"IOData.html#to_binary!/3"},{"type":"function","title":"IOData.to_iodata/1","doc":"Returns the data in iodata form without modifying it.","ref":"IOData.html#to_iodata/1"},{"type":"function","title":"IOData.to_iodata/3","doc":"Extracts a portion of the data as iodata, starting at 'start' for 'count' bytes. Returns an ok/error tuple.","ref":"IOData.html#to_iodata/3"},{"type":"function","title":"IOData.to_iodata!/1","doc":"Same as to_iodata/1 but raises an error if the data is insufficient.","ref":"IOData.html#to_iodata!/1"},{"type":"function","title":"IOData.to_iodata!/3","doc":"Same as to_iodata/3 but raises an error if the data is insufficient.","ref":"IOData.html#to_iodata!/3"},{"type":"module","title":"IOData.Slice","doc":"A module for handling slices of IO data.\n\nThis module provides a way to work with slices of IO data, allowing you to\nwrap a portion of IO data and perform operations such as checking the size,\nsplitting, and converting to binary or IO data.","ref":"IOData.Slice.html"},{"type":"module","title":"Types - IOData.Slice","doc":"* `t/0` - The type representing a slice of IO data.","ref":"IOData.Slice.html#module-types"},{"type":"module","title":"Functions - IOData.Slice","doc":"* `wrap/3` - Wraps a portion of IO data into a slice.","ref":"IOData.Slice.html#module-functions"},{"type":"module","title":"Examples - IOData.Slice","doc":"iex> slice = IOData.Slice.wrap(\"hello world\", 0, 5)\n    %IOData.Slice{iodata: \"hello world\", start: 0, count: 5}\n\n    iex> IOData.at_least?(slice, 3)\n    true\n\n    iex> IOData.split(slice, 2)\n    {:ok, {%IOData.Slice{iodata: \"hello world\", start: 0, count: 2}, %IOData.Slice{iodata: \"hello world\", start: 2, count: 3}}}\n\n    iex> IOData.to_binary(slice)\n    {:ok, \"hello\"}","ref":"IOData.Slice.html#module-examples"},{"type":"type","title":"IOData.Slice.t/0","doc":"","ref":"IOData.Slice.html#t:t/0"},{"type":"function","title":"IOData.Slice.wrap/3","doc":"Wraps a portion of IO data into a slice.","ref":"IOData.Slice.html#wrap/3"},{"type":"function","title":"Parameters - IOData.Slice.wrap/3","doc":"* `iodata` - The IO data to wrap.\n  * `start` - The starting position of the slice.\n  * `count` - The number of bytes in the slice (optional).","ref":"IOData.Slice.html#wrap/3-parameters"},{"type":"function","title":"Examples - IOData.Slice.wrap/3","doc":"iex> IOData.Slice.wrap(\"hello world\", 0, 5)\n    %IOData.Slice{iodata: \"hello world\", start: 0, count: 5}","ref":"IOData.Slice.html#wrap/3-examples"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.36.1"}}